@@ -1,11 +1,11 @@
 # test line added
 # test demo team
 from flask import Flask, render_template, request
-#from dataLoad.data_loader import DataGetter
-#from dataPreprocessing.preProcess import Preprocessor
-#from dataVisualization.visualization import DataVisualization
-#from modelTraining.classificationModels import ClassificationModelTuner
-#from prediction.predict import Prediction
+from dataLoad.data_loader import DataGetter
+from dataPreprocessing.preProcess import Preprocessor
+from dataVisualization.visualization import DataVisualization
+from modelTraining.classificationModels import ClassificationModelTuner
+from prediction.predict import Prediction
 
 app = Flask(__name__)
 
